@@ -11,7 +11,7 @@ use pepper::{
     mode::ModeKind,
     picker::Picker,
     plugin::PluginHandle,
-    word_database::{WordIndicesIter, WordKind},
+    word_database::WordKind,
 };
 
 use crate::{
@@ -631,7 +631,10 @@ pub(crate) fn on_response(
                     let surrounding_len = context_len - 1;
                     let start =
                         (location.range.start.line as usize).saturating_sub(surrounding_len);
-                    let end = location.range.end.line as usize + surrounding_len;
+                    let end = context_buffer
+                        .lines()
+                        .len()
+                        .min(location.range.end.line as usize + surrounding_len);
 
                     for line in context_buffer.lines()[start..=end]
                         .iter()
@@ -974,7 +977,9 @@ pub(crate) fn on_response(
                 WordKind::Identifier => word.text,
                 _ => "",
             };
-            ctx.editor.picker.filter(WordIndicesIter::empty(), filter);
+            ctx.editor
+                .picker
+                .filter_completion(ctx.editor.word_database.word_indices(), filter);
 
             Ok(())
         }
